@@ -493,6 +493,7 @@ func TestActuator(t *testing.T) {
 		},
 		{
 			name: "Delete machine failed (no running instances)",
+
 			describeInstancesOutput: &ec2.DescribeInstancesOutput{
 				Reservations: []*ec2.Reservation{
 					{
@@ -506,6 +507,7 @@ func TestActuator(t *testing.T) {
 		},
 		{
 			name: "Delete machine failed (error terminating instances)",
+
 			terminateInstancesErr: fmt.Errorf("error"),
 			operation: func(objectClient client.Client, actuator *Actuator, cluster *clusterv1.Cluster, machine *machinev1.Machine) {
 				actuator.Delete(context.TODO(), cluster, machine)
@@ -642,7 +644,7 @@ func TestAvailabiltyZone(t *testing.T) {
 			if tc.availabilityZone != "" && tc.subnet == "" {
 				placement = &ec2.Placement{AvailabilityZone: aws.String(tc.availabilityZone)}
 			}
-
+			az := "us-east-1a"
 			mockAWSClient.EXPECT().RunInstances(placementMatcher{placement}).Return(
 				&ec2.Reservation{
 					Instances: []*ec2.Instance{
@@ -653,6 +655,9 @@ func TestAvailabiltyZone(t *testing.T) {
 								Name: aws.String("Running"),
 							},
 							LaunchTime: aws.Time(time.Now()),
+							Placement: &ec2.Placement{
+								AvailabilityZone: &az,
+							},
 						},
 					},
 				}, nil)
